@@ -1,9 +1,9 @@
 package Acme::PERLANCAR::Dummy;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-03-26'; # DATE
+our $DATE = '2021-07-18'; # DATE
 our $DIST = 'Acme-PERLANCAR-Dummy'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 1;
 # ABSTRACT: Dummy distribution for various testing
@@ -20,7 +20,7 @@ Acme::PERLANCAR::Dummy - Dummy distribution for various testing
 
 =head1 VERSION
 
-This document describes version 0.007 of Acme::PERLANCAR::Dummy (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-03-26.
+This document describes version 0.008 of Acme::PERLANCAR::Dummy (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-07-18.
 
 =head1 HOMEPAGE
 
@@ -32,7 +32,7 @@ Source repository is at L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-PERLANCAR-Dummy>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
